@@ -1,22 +1,29 @@
-#' Address search API for OSM elements
+#' Address search API for OSM elements (free-form query)
 #'
 #' @description
 #' Geocodes addresses given as character values. This function returns the
-#' \CRANpkg{tibble} associated with the query, see [geo_lite_sf()] for
-#' retrieving the data as a spatial object (\CRANpkg{sf} format).
+#' [`tibble`][tibble::tibble] associated with the query, see [geo_lite_sf()] for
+#' retrieving the data as a spatial object ([`sf`][sf::st_sf] format).
 #'
-#' @param address character with single line address, e.g.
+#' This function correspond to the **free-form query** search described in the
+#' [API endpoint](https://nominatim.org/release-docs/develop/api/Search/).
+#'
+#' @family geocoding
+#'
+#' @param address `character` with single line address, e.g.
 #'   (`"1600 Pennsylvania Ave NW, Washington"`) or a vector of addresses
 #'   (`c("Madrid", "Barcelona")`).
-#' @param lat	latitude column name in the output data (default  `"lat"`).
-#' @param long	longitude column name in the output data (default  `"long"`).
-#' @param limit	maximum number of results to return per input address. Note
+#' @param lat	Latitude column name in the output data (default  `"lat"`).
+#' @param long Longitude column name in the output data (default  `"long"`).
+#' @param limit	Maximum number of results to return per input address. Note
 #'   that each query returns a maximum of 50 results.
-#' @param full_results returns all available data from the API service.
+#' @param full_results Returns all available data from the API service.
 #'    If `FALSE` (default) only latitude, longitude and address columns are
 #'    returned. See also `return_addresses`.
-#' @param return_addresses return input addresses with results if `TRUE`.
-#' @param verbose if `TRUE` then detailed logs are output to the console.
+#' @param return_addresses Return input addresses with results if `TRUE`.
+#' @param verbose If `TRUE` then detailed logs are output to the console.
+#' @param nominatim_server The URL of the Nominatim server to use.
+#'    Defaults to `"https://nominatim.openstreetmap.org/"`.
 #' @param progressbar Logical. If `TRUE` displays a progress bar to indicate
 #'   the progress of the function.
 #' @param custom_query A named list with API-specific parameters to be used
@@ -27,7 +34,16 @@
 #' See <https://nominatim.org/release-docs/latest/api/Search/> for additional
 #' parameters to be passed to `custom_query`.
 #'
-#' @return A \CRANpkg{tibble} with the results.
+#' @return
+#'
+#' ```{r child = "man/chunks/tibbleout.Rmd"}
+#' ```
+#'
+#'
+#' @seealso
+#' [geo_lite_sf()], [tidygeocoder::geo()].
+#'
+#' @export
 #'
 #' @examplesIf nominatim_check_access()
 #' \donttest{
@@ -42,10 +58,6 @@
 #'   full_results = TRUE
 #' )
 #' }
-#' @export
-#'
-#' @seealso [geo_lite_sf()], [tidygeocoder::geo()]
-#' @family geocoding
 geo_lite <- function(address,
                      lat = "lat",
                      long = "lon",
@@ -53,6 +65,7 @@ geo_lite <- function(address,
                      full_results = FALSE,
                      return_addresses = TRUE,
                      verbose = FALSE,
+                     nominatim_server = "https://nominatim.openstreetmap.org/",
                      progressbar = TRUE,
                      custom_query = list()) {
   if (limit > 50) {
@@ -90,6 +103,7 @@ geo_lite <- function(address,
       full_results,
       return_addresses,
       verbose,
+      nominatim_server = nominatim_server,
       custom_query
     )
   })
@@ -111,15 +125,18 @@ geo_lite_single <- function(address,
                             full_results = TRUE,
                             return_addresses = TRUE,
                             verbose = FALSE,
+                            nominatim_server =
+                              "https://nominatim.openstreetmap.org/",
                             custom_query = list()) {
-  # Step 1: Download ----
-  api <- "https://nominatim.openstreetmap.org/search?q="
+  # First build the api address. If the passed nominatim_server does not end
+  # with a trailing forward-slash, add one
+  api <- prepare_api_url(nominatim_server, "search?q=")
 
   # Replace spaces with +
   address2 <- gsub(" ", "+", address)
 
   # Compose url
-  url <- paste0(api, address2, "&format=json&limit=", limit)
+  url <- paste0(api, address2, "&format=jsonv2&limit=", limit)
 
   if (full_results) url <- paste0(url, "&addressdetails=1")
 
@@ -136,13 +153,11 @@ geo_lite_single <- function(address,
   tbl_query <- dplyr::tibble(query = address)
 
 
-  # nocov start
   if (isFALSE(res)) {
     message(url, " not reachable.")
     out <- empty_tbl(tbl_query, lat, long)
     return(invisible(out))
   }
-  # nocov end
 
 
   result <- dplyr::as_tibble(jsonlite::fromJSON(json, flatten = TRUE))
